import threading

from source import packets
from source.behaviors import events


class Manager:
    def __init__(self, interface: str):
        from . import CommunicationManager, EventManager, RoleManager

        # communication manager
        self.communication = CommunicationManager(self, interface)
        self.communication.register_packet_type(b"DISC", packets.DiscoveryPacket)

        # event manager
        self.event = EventManager(self)
        self.event.register_event_handler(packets.DiscoveryPacket, events.DiscoveryEvent())

        # role manager
        self.role = RoleManager(self)

    def loop(self):
        # run a thread for the event and the role manager
        event_thread = threading.Thread(target=self.event.loop)
        role_thread = threading.Thread(target=self.role.loop)

        event_thread.start()
        role_thread.start()

        event_thread.join()
        role_thread.join()